|
| Wumpus.MicroPrint | | Portability | GHC | | Stability | unstable | | Maintainer | stephen.tetley@gmail.com |
|
|
|
|
|
| Description |
| MicroPrints
|
|
| Synopsis |
|
|
|
|
| Re-export all MicroPrint.Render
|
|
|
DrawWordF :
(num_chars, char_unit_width) * (full_width, full_height) -> rgb -> DGraphicF
The libraries currently provides two styles - greekF and
borderedF.
|
|
|
| Style properties for micro-print drawing.
| | Constructors | | Instances | |
|
|
|
| Draw the word as a single coloured rectangle.
|
|
|
| Draw the word as a coloured rectangle, with a border grid.
|
|
|
|
| Top level rendering functions
|
|
|
Build a picture from a MicroPrint.
This function returns Nothing if the picture is empty.
|
|
|
Build a picture from a MicroPrint - unsafe version.
This function throws a runtime error if the picture is empty.
|
|
| Re-export some from MicroPrint.DrawMonad
|
|
|
Build a microprint within a monad...
Drawings are made in a teletype fashion emitting a character,
space or line-break at each step.
| Instances | |
|
|
|
|
|
|
|
|
| Emit a linebreak in the output.
|
|
|
Change the current drawing colour.
Note - it is permissible to change colour mid-word, but this
is the same as having a no-space break.
|
|
|
| Draw a character - note in the microprint, characters will
be concatenated together to make a word.
|
|
|
| Draw a space.
|
|
| Produced by Haddock version 2.6.1 |